<?php

namespace Drupal\contact_mail\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Render\Markup;

/**
 * Contact_mail hook_mail_alter().
 */
class HookMailAlter extends ControllerBase {

  /**
   * Hook init.
   */
  public static function hook(&$message) {
    if ($message['id'] == 'contact_page_mail') {
      $config = \Drupal::config('contact_mail.settings');
      // Rewrite submission template.
      if ($config->get('tpl') && isset($message['params']['contact_message'])) {
        // Mail extra information.
        $message['body'][0] .= Markup::create(self::getWarning($config));
        // Rewrite submission template.
        $message['body'][1] = Markup::create(self::getMessage($message));
      }
      // Add e-mail Recipients.
      self::addEmails($config, $message);
      // Send html (instead txt).
      if ($config->get('html')) {
        $message['headers']['Content-Type'] = 'text/html';
      }
    }
  }

  /**
   * Add e-mail Recipients.
   */
  public static function addEmails($config, &$message) {
    if ($config->get('emails')) {
      $to = [];
      $to[] = $message['to'];
      $emails = $config->get('emails');
      $emails = explode("\n", $emails);
      foreach ($emails as $email) {
        if (strpos($email, "@") && strpos($email, ".")) {
          $to[] = trim($email);
        }
      }
      $message['to'] = implode(', ', $to);
    }
  }

  /**
   * Submission template.
   */
  public static function getMessage($message) {
    $submission = $message['params']['contact_message']->toArray();
    $form = $message['params']['contact_form']->toArray();
    $msg = [];
    foreach ($submission as $key => $value) {
      if (strpos($key, 'field_') !== FALSE) {
        $fieldDefinition = $message['params']['contact_message']->$key->getFieldDefinition();
        $label = $fieldDefinition->label();
        $val = '—';
        if (isset($value[0]['value'])) {
          $val = $value[0]['value'];
        }
        $msg["field-$key"] = [
          '#prefix' => "<div>",
          'title' => ['#markup' => "<b>$label:</b> "],
          'data' => ['#markup' => $val],
          '#suffix' => "</div>\n",
        ];
      }
    }
    return \Drupal::service('renderer')->render($msg);
  }

  /**
   * Mail extra information.
   */
  public static function getWarning($config) {
    $warning['#markup'] = $config->get('header');
    $html = \Drupal::service('renderer')->render($warning);
    return $html;
  }

}
